@@ -1,19 +1,25 @@
 ; -*- Lisp -*-
 (in-package :maxima)
 
-(defparameter *autoconf-variables-set* "@variables_set@")
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.37.3")
+(defparameter *autoconf-version* "5.43.2")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/libexec")
 (defparameter *autoconf-datadir* "/usr/share")
 (defparameter *autoconf-infodir* "/usr/share/info")
-(defparameter *autoconf-host* "x86_64-unknown-cygwin")
+(defparameter *autoconf-host* "x86_64-pc-cygwin")
+;; This variable is kept for backwards compatibiliy reasons:
+;; We seem to be in the fortunate position that we sometimes need to check for windows.
+;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
 (defparameter *autoconf-win32* "false")
+(defparameter *autoconf-windows* "false")
 (defparameter *autoconf-ld-flags* "")
+
+;; This will be T if this was a lisp-only build
+(defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-src-root* "/mnt/share/maint/maxima.x86_64/src/cygwin-branch-5_37-e93959a")
+(defparameter *maxima-src-root* "/mnt/share/cygpkgs/maxima/maxima.x86_64/build")
 (defparameter *maxima-build-root* "@expanded_top_builddir@")
 (defparameter *maxima-default-layout-autotools* "true")
